@@ -468,7 +468,7 @@ class MyForm(QtGui.QMainWindow):
 		quit()
 	
 	def setLastfm(self):
-		username,ok = QtGui.QInputDialog.getText(self,"Username", "Last.fm Username:")
+		username,ok = QtGui.QInputDialog.getText(self,"Username", "Last.fm Username:",QLineEdit.Normal,self.c.lastfm_user)
 		if ok:
 			self.c.lastfm_user = username
 		password,ok =  QtGui.QInputDialog.getText(self,"Password", "Last.fm Password:",QLineEdit.Password)
